==> libxkbcommon-doc-1.12.0-2-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_c.js <==
var searchData=
[
  ['cancellation_20behavior_0',['Cancellation Behavior',['../group__compose.html',1,'']]],
  ['cannot_20infer_20key_20type_1',['XKB-183 – Cannot infer key type',['../error-index.html#XKB-183',1,'']]],
  ['cannot_20resolve_20rmlvo_2',['XKB-595 – Cannot resolve rmlvo',['../error-index.html#XKB-595',1,'']]],
  ['canonical_20and_20non_20canonical_20modifiers_3',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
  ['canonical_20modifiers_4',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
  ['cards_5',['Wild cards',['../rule-file-format.html#rules-wildcard-def',1,'']]],
  ['changes_6',['changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes']]],
  ['char_20escape_20sequence_7',['XKB-645 – Unknown char escape sequence',['../error-index.html#XKB-645',1,'']]],
  ['client_20state_8',['Server State and Client State',['../group__state.html',1,'']]],
  ['code_9',['Code',['../md_doc_2quick-guide.html#code',1,'']]],
  ['codes_10',['Example: key codes',['../rule-file-format.html#example-key-codes',1,'']]],
  ['combination_20to_20switch_20between_20layouts_20not_20work_11',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['comments_12',['Comments',['../keymap-text-format-v1-v2.html#comments',1,'']]],
  ['compatibility_13',['Compatibility',['../user-configuration.html#compatibility',1,'Compatibility'],['../xkbcommon-compatibility.html',1,'XKB Compatibility']]],
  ['compilation_20failed_14',['XKB-822 – Keymap compilation failed',['../error-index.html#XKB-822',1,'']]],
  ['components_15',['Keymap components',['../keymap-text-format-v1-v2.html#keymap-components-intro',1,'']]],
  ['compose_20locale_16',['Compose Locale',['../group__compose.html',1,'']]],
  ['compose_20locale_17',['XKB-679 – Invalid compose locale',['../error-index.html#XKB-679',1,'']]],
  ['compose_20support_18',['Compose support',['../xkbcommon-compatibility.html#compose-support',1,'Compose support'],['../todo.html#_todo000006',1,'Compose support'],['../todo.html#_todo000007',1,'Compose support']]],
  ['compose_20syntax_19',['XKB-685 – Invalid compose syntax',['../error-index.html#XKB-685',1,'']]],
  ['configuration_20',['configuration',['../debugging.html#testing-custom-config',1,'Testing a custom configuration'],['../user-configuration.html',1,'User-configuration'],['../xkb-intro.html#xkb-the-config',1,'XKB the keyboard keymap configuration']]],
  ['conflicting_20key_20action_21',['XKB-883 – Conflicting key action',['../error-index.html#XKB-883',1,'']]],
  ['conflicting_20key_20fields_22',['XKB-935 – Conflicting key fields',['../error-index.html#XKB-935',1,'']]],
  ['conflicting_20key_20name_23',['XKB-523 – Conflicting key name',['../error-index.html#XKB-523',1,'']]],
  ['conflicting_20key_20symbol_24',['XKB-461 – Conflicting key symbol',['../error-index.html#XKB-461',1,'']]],
  ['conflicting_20key_20symbols_20entry_25',['XKB-901 – Conflicting key symbols entry',['../error-index.html#XKB-901',1,'']]],
  ['conflicting_20key_20type_20definitions_26',['XKB-407 – Conflicting key type definitions',['../error-index.html#XKB-407',1,'']]],
  ['conflicting_20key_20type_20level_20names_27',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
  ['conflicting_20key_20type_20map_20entry_28',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['conflicting_20key_20type_20merging_20groups_29',['XKB-893 – Conflicting key type merging groups',['../error-index.html#XKB-893',1,'']]],
  ['conflicting_20key_20type_20preserve_20entries_30',['XKB-043 – Conflicting key type preserve entries',['../error-index.html#XKB-043',1,'']]],
  ['conflicting_20modmap_31',['Conflicting modmap',['../error-index.html#XKB-800',1,'XKB-800 – Conflicting modmap'],['../todo.html#_todo000021',1,'XKB-800 – Conflicting modmap']]],
  ['conflicting_20sequences_32',['Conflicting Sequences',['../group__compose.html',1,'']]],
  ['consumed_20modifiers_33',['Consumed Modifiers',['../group__state.html',1,'']]],
  ['control_20flags_20actions_34',['Control flags actions',['../keymap-text-format-v1-v2.html#control-flags-actions',1,'']]],
  ['count_35',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['credits_36',['Credits',['../index.html#credits',1,'']]],
  ['custom_20configuration_37',['Testing a custom configuration',['../debugging.html#testing-custom-config',1,'']]],
  ['custom_20layout_20without_20installing_20it_38',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['customize_20my_20layout_39',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]]
];

==> libxkbcommon-doc-1.13.1-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_c.js <==
var searchData=
[
  ['cancellation_20behavior_0',['Cancellation Behavior',['../group__compose.html',1,'']]],
  ['cannot_20infer_20key_20type_1',['XKB-183 – Cannot infer key type',['../error-index.html#XKB-183',1,'']]],
  ['cannot_20resolve_20rmlvo_2',['XKB-595 – Cannot resolve rmlvo',['../error-index.html#XKB-595',1,'']]],
  ['canonical_20and_20non_20canonical_20modifiers_3',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
  ['canonical_20modifiers_4',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
  ['cards_5',['Wild cards',['../rule-file-format.html#rules-wildcard-def',1,'']]],
  ['changes_6',['changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes'],['../release-notes.html#breaking-changes-11',1,'Breaking changes']]],
  ['char_20escape_20sequence_7',['XKB-645 – Unknown char escape sequence',['../error-index.html#XKB-645',1,'']]],
  ['client_20state_8',['Server State and Client State',['../group__state.html',1,'']]],
  ['code_9',['Code',['../md_doc_2quick-guide.html#code',1,'']]],
  ['codes_10',['Example: key codes',['../rule-file-format.html#example-key-codes',1,'']]],
  ['combination_20to_20switch_20between_20layouts_20not_20work_11',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['comments_12',['Comments',['../keymap-text-format-v1-v2.html#comments',1,'']]],
  ['compatibility_13',['Compatibility',['../user-configuration.html#compatibility',1,'Compatibility'],['../xkbcommon-compatibility.html',1,'XKB Compatibility']]],
  ['compilation_20failed_14',['XKB-822 – Keymap compilation failed',['../error-index.html#XKB-822',1,'']]],
  ['components_15',['Keymap components',['../keymap-text-format-v1-v2.html#keymap-components-intro',1,'']]],
  ['compose_20locale_16',['Compose Locale',['../group__compose.html',1,'']]],
  ['compose_20locale_17',['XKB-679 – Invalid compose locale',['../error-index.html#XKB-679',1,'']]],
  ['compose_20support_18',['Compose support',['../xkbcommon-compatibility.html#compose-support',1,'Compose support'],['../todo.html#_todo000006',1,'Compose support'],['../todo.html#_todo000007',1,'Compose support']]],
  ['compose_20syntax_19',['XKB-685 – Invalid compose syntax',['../error-index.html#XKB-685',1,'']]],
  ['configuration_20',['configuration',['../debugging.html#testing-custom-config',1,'Testing a custom configuration'],['../user-configuration.html',1,'User-configuration'],['../xkb-intro.html#xkb-the-config',1,'XKB the keyboard keymap configuration']]],
  ['conflicting_20key_20action_21',['XKB-883 – Conflicting key action',['../error-index.html#XKB-883',1,'']]],
  ['conflicting_20key_20fields_22',['XKB-935 – Conflicting key fields',['../error-index.html#XKB-935',1,'']]],
  ['conflicting_20key_20name_23',['XKB-523 – Conflicting key name',['../error-index.html#XKB-523',1,'']]],
  ['conflicting_20key_20symbol_24',['XKB-461 – Conflicting key symbol',['../error-index.html#XKB-461',1,'']]],
  ['conflicting_20key_20symbols_20entry_25',['XKB-901 – Conflicting key symbols entry',['../error-index.html#XKB-901',1,'']]],
  ['conflicting_20key_20type_20definitions_26',['XKB-407 – Conflicting key type definitions',['../error-index.html#XKB-407',1,'']]],
  ['conflicting_20key_20type_20level_20names_27',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
  ['conflicting_20key_20type_20map_20entry_28',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['conflicting_20key_20type_20merging_20groups_29',['XKB-893 – Conflicting key type merging groups',['../error-index.html#XKB-893',1,'']]],
  ['conflicting_20key_20type_20preserve_20entries_30',['XKB-043 – Conflicting key type preserve entries',['../error-index.html#XKB-043',1,'']]],
  ['conflicting_20modmap_31',['Conflicting modmap',['../error-index.html#XKB-800',1,'XKB-800 – Conflicting modmap'],['../todo.html#_todo000021',1,'XKB-800 – Conflicting modmap']]],
  ['conflicting_20sequences_32',['Conflicting Sequences',['../group__compose.html',1,'']]],
  ['consumed_20modifiers_33',['Consumed Modifiers',['../group__state.html',1,'']]],
  ['control_20flags_20actions_34',['Control flags actions',['../keymap-text-format-v1-v2.html#control-flags-actions',1,'']]],
  ['count_35',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['credits_36',['Credits',['../index.html#credits',1,'']]],
  ['custom_20configuration_37',['Testing a custom configuration',['../debugging.html#testing-custom-config',1,'']]],
  ['custom_20layout_20without_20installing_20it_38',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['customize_20my_20layout_39',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]]
];
